Learn R Programming

PALMO (version 0.1.2)

mergePALMOdata: mergePALMOdata Function

Description

This function allows to merge expression data from bulk or single cell data with annotation file provided by user. It will remove the annotations with missing information from Sample name, donor/participant and time variable.

Usage

mergePALMOdata(data_object, datatype)

Value

PALMO object with merged annotation and data matrix

Arguments

data_object

Input PALMO S4 object. It contains annotation information and expression data from Bulk or single cell data.

datatype

Input data type 'bulk' or 'singlecell'

Examples

Run this code
if (FALSE) {
palmo_obj <- mergePALMOdata(data_object=palmo_obj)
}

Run the code above in your browser using DataLab