This function allows ser to calculate differential expressed genes in the direction of given time points (if timepoints>3 otherwise DEGs between two timepoints). A hurdle model was fit to each participant independently in order to identify participant-specific longitudinal transcriptomic changes. Genes that were expressed in at least 10% of cells per participant were considered for this analysis. The models were fit on the input normalized data, modeling the timepoints as a continuous variable within each cell type and adjusting for the batch only if any timepoints from the same participant were run across multiple batches.
sclongitudinalDEG(
data_object,
scassay = "RNA",
group_column,
group_oi = NULL,
mincellsexpressed = 0.1,
removelnc = "TRUE",
adjfac = NULL,
baseline = NULL,
addCDR = FALSE,
CDR_column = NULL,
plotWidth = 10,
plotHeight = 10,
fileName = NULL,
filePATH = NULL
)Input PALMO S4 object. It contains annotation information and expression data from Bulk or single cell data.
Single cell assay from scRNA seurat object (Default "RNA")
Column of interest such as "celltype" to analyze DEGs in participant over time
Features of interest such as specific celltypes c("CD4_Naive", "CD4_TEM")
Average expression threshold to filter lowly expressed genes/features Default is 0.1
Remove lincRNAs, mitochondrial and ribosomal genes from analysis incldes (^RP|^MT-|^LINC|orf) (TRUE/FALSE). Default is TRUE
Factors to be adjusted for such as batch, sex
Donors (PTID) to be considered as baseline. Deafult NULL
(Optional) Add CDR while performing differential analysis. Default is FALSE
(Optional) cellular detection rate column name
User-defined plot width, Default 10 in
User-defined plot height, Default 10 in
User-defined file name, Default outputFile
User-defined output directory PATH Default, current directory
if (FALSE) {
palmo_obj <- sclongitudinalDEG(ann=metadata, dataObj=pbmc, scassay="RNA",
group_column="celltype")
}
Run the code above in your browser using DataLab