This function allows to merge expression data from bulk or single cell data
with annotation file provided by user. It will remove the annotations with
missing information from Sample name, donor/participant and time variable.
Usage
mergePALMOdata(data_object, datatype)
Value
PALMO object with merged annotation and data matrix
Arguments
data_object
Input PALMO S4 object. It contains annotation
information and expression data from Bulk or single cell data.